#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2013 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys

lib_path = os.path.abspath('../')
sys.path.append(lib_path)

from smartlingApiSdk.SmartlingDirective import SmartlingDirective
from nose.tools import assert_equal
from nose.tools import raises


class test_SmartlingDirective(object):
    def test_init(self):
        d = SmartlingDirective("placeholder_format_custom", "%s")
        assert_equal(d.name, "placeholder_format_custom")
        assert_equal(d.value, "%s")

        d1 = SmartlingDirective("plaCeholder_Format_cusTom", None)
        assert_equal(d1.name, "placeholder_format_custom")
        assert_equal(d1.value, "")

    @raises(Exception)
    def test_init_empty_name(self):
        SmartlingDirective("", "%s")

    @raises(Exception)
    def test_init_None_name(self):
        SmartlingDirective(None, "%s")

    def test_remove_sl_prefix(self):
        d = SmartlingDirective("smartling.placeholder_format_custom", "%s")
        assert_equal(d.name, "placeholder_format_custom")

        d2 = SmartlingDirective("sl.placeholder_format_custom", "%s")
        assert_equal(d2.name, "sl.placeholder_format_custom")

        d3 = SmartlingDirective("smartling.placeholder_format_custom smartling.none", "%s")
        assert_equal(d3.name, "placeholder_format_custom smartling.none")



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

class ProxySettings:
    """ settings for http proxy to be used to pass api requests, !!! Only basic authentication is supported for restricted proxy access !!! """
    def __init__(self, username, passwd, host, port):
        self.username = username
        self.passwd = passwd
        self.host = host
        self.port = port


#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''
import os

class CredentialsNotSet(Exception):
    noKeymessage = """ 
     don't forget to set real MY_PROJECT_ID, MY_USER_IDENTIFIER, MY_USER_SECRET, MY_LOCALE
     in SetCredentials class
     or use environment variables:
     export SL_LOCALE=**-**
     export SL_USER_IDENTIFIER=******************************
     export SL_USER_SECRET=*******************************************************
     
     #optional
     export SL_ACCOUNT_UID=******* #required only to list projects api call
     export SL_PROJECT_ID=******* #required for api calls `projects` and `project_details`
    """

    def __init__(self, id):
        self.id = id
        
    def __str__(self):
        return "Missing:" + self.id + self.noKeymessage


class Credentials:

    MY_PROJECT_ID = "CHANGE_ME"
    MY_ACCOUNT_UID = "CHANGE_ME"
    MY_USER_IDENTIFIER = "CHANGE_ME"
    MY_USER_SECRET = "CHANGE_ME"
    MY_LOCALE="CHANGE_ME"
    
    creds = ("PROJECT_ID", "ACCOUNT_UID", "USER_IDENTIFIER", "USER_SECRET", "LOCALE")
    optional_creds = ("ACCOUNT_UID")
   
    def __init__(self):
        for id in self.creds:
            cred = "MY_"+id
            if "CHANGE_ME" == getattr(self, cred, "CHANGE_ME"):
                value = os.environ.get('SL_'+id, getattr(self, cred))    
            if "CHANGE_ME" == value and not id in self.optional_creds:
                raise CredentialsNotSet(id)
            setattr(self, cred, value)



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2013 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys

lib_path = os.path.abspath('../')
sys.path.append(lib_path)

from smartlingApiSdk.UploadData import UploadData
from smartlingApiSdk.SmartlingDirective import SmartlingDirective
from nose.tools import assert_equal


class test_UploadData(object):
    def test_init(self):
        ud = UploadData("path", "name", "type")
        assert_equal(ud.path, "path")
        assert_equal(ud.name, "name")
        assert_equal(ud.type, "type")
        assert_equal(ud.type, "type")
        assert_equal(ud.approveContent, "false")
        assert_equal(ud.callbackUrl, "")

    def test_setApproveContent(self):
        ud = UploadData("path", "name", "type")
        ud.setApproveContent("true")
        assert_equal(ud.approveContent, "true")

    def test_setCallbackUrl(self):
        ud = UploadData("path", "name", "type")
        ud.setCallbackUrl("smartling.com")
        assert_equal(ud.callbackUrl, "smartling.com")

    def test_addDirective(self):
        ud = UploadData("path", "name", "type")
        assert_equal(len(ud.directives), 0)

        ud.addDirective(SmartlingDirective("name", "value"))
        assert_equal(len(ud.directives), 1)
        assert_equal(ud.directives[0].name, "name")

        ud.addDirective(SmartlingDirective("name2", "value2"))
        assert_equal(len(ud.directives), 2)
        assert_equal(ud.directives[1].value, "value2")



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2013 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys

lib_path = os.path.abspath('../')
sys.path.append(lib_path)

from smartlingApiSdk.SmartlingDirective import SmartlingDirective
from smartlingApiSdk.FileApiBase import FileApiBase
from smartlingApiSdk.UploadData import UploadData
from smartlingApiSdk.Constants import Params
from nose.tools import assert_equal


class test_UploadData(object):
    def mock_uploadMultipart(self, uri, params):
        return params

    def test_commandUpload(self):
        ud = UploadData("path", "name", "type")

        api = FileApiBase("host", "apiKey", "projectId")
        api.uploadMultipart = self.mock_uploadMultipart
        params = api.commandUpload(ud)

        assert_equal(len(params), 4)
        assert_equal(params[Params.FILE_URI], "name")
        assert_equal(params[Params.FILE_TYPE], "type")
        assert_equal(params[Params.FILE_PATH], "pathname")
        assert_equal(params[Params.APPROVED], "false")

    def test_commandUpload_Callback_Approved(self):
        ud = UploadData("path", "name", "type")
        ud.setApproveContent("true")
        ud.setCallbackUrl("smartling.com")

        api = FileApiBase("host", "apiKey", "projectId")
        api.uploadMultipart = self.mock_uploadMultipart
        params = api.commandUpload(ud)

        assert_equal(len(params), 5)
        assert_equal(params[Params.APPROVED], "true")
        assert_equal(params[Params.CALLBACK_URL], "smartling.com")

    def test_commandUpload_Directives(self):
        ud = UploadData("path", "name", "type")
        ud.setApproveContent("true")
        ud.setCallbackUrl("smartling.com")
        ud.addDirective(SmartlingDirective("placeholder_format_custom", "\[.+?\]"))
        ud.addDirective(SmartlingDirective("placeholder_format", "IOS"))

        api = FileApiBase("host", "apiKey", "projectId")
        api.uploadMultipart = self.mock_uploadMultipart
        params = api.commandUpload(ud)

        assert_equal(len(params), 7)
        assert_equal(params["smartling.placeholder_format_custom"], "\[.+?\]")
        assert_equal(params["smartling.placeholder_format"], "IOS")



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys
import time

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApiSdk.SmartlingFileApi import SmartlingFileApi, SmartlingFileApiFactory
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.UploadData import UploadData
from nose.tools import assert_equal

noKeymessage = """ don't forget to set real API_KEY and PROJECT_ID
 or use environment variables:
 export SL_API_KEY=********-****-****-****-************
 export SL_PROJECT_ID=*******
"""

class testFapi(object):
    MY_API_KEY = "YOUR_API_KEY"
    MY_PROJECT_ID = "YOUR_PROJECT_ID"

    FILE_NAME = "java.properties"
    FILE_NAME_16 = "javaUTF16.properties"
    FILE_TYPE = "javaProperties"
    FILE_PATH = "../resources/"
    FILE_NAME_NEW = "java.properties.renamed"
    FILE_NAME_NEW_16 = "javaUTF16.properties.renamed"

    CALLBACK_URL = "http://google.com/?q=hello"

    CODE_SUCCESS_TOKEN = '"code":"SUCCESS"'

    def setUp(self):
        self.MY_API_KEY = os.environ.get('SL_API_KEY', self.MY_API_KEY)
        self.MY_PROJECT_ID = os.environ.get('SL_PROJECT_ID', self.MY_PROJECT_ID)
        if self.MY_PROJECT_ID == "YOUR_PROJECT_ID":
            raise noKeymessage 
        
        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None        
        self.fapi = SmartlingFileApiFactory().getSmartlingTranslationApi(self.MY_API_KEY, self.MY_PROJECT_ID, proxySettings)
        self.locale =  os.environ.get('SL_LOCALE', "ru-RU")
        timestamp = `time.time()`
        self.uri = self.FILE_NAME + timestamp 
        self.doUpload(self.FILE_NAME, self.uri)

        self.uri16 = self.FILE_NAME_16 + timestamp 
        self.doUpload(self.FILE_NAME_16, self.uri16)


    def tearDown(self):
        res, status = self.fapi.delete(self.uri)
        res, status = self.fapi.delete(self.uri16)

    def doUpload(self, name, uri):
        #ensure file is uploaded which is necessary for all tests
        uploadData = UploadData(self.FILE_PATH, name, self.FILE_TYPE)
        uploadData.setUri(uri)
        uploadData.setCallbackUrl(self.CALLBACK_URL)
        return self.fapi.upload(uploadData)

    def testFileList(self):
        res, status = self.fapi.list()
        assert_equal(True, res.find(self.CODE_SUCCESS_TOKEN) > 0)

    def testFileStatus(self):
        res, status = self.fapi.status(self.uri, self.locale)
        assert_equal(True, res.find(self.CODE_SUCCESS_TOKEN) > 0)
        
        res, status = self.fapi.status(self.uri16, self.locale)
        assert_equal(True, res.find(self.CODE_SUCCESS_TOKEN) > 0)

    def testGetFileFromServer(self):
        res, status = self.fapi.get(self.uri, self.locale)
        lines = open(self.FILE_PATH + self.FILE_NAME, "rb").readlines()
        assert_equal(len(res.split("\n")), len(lines))

        res, status = self.fapi.get(self.uri16, self.locale)
        lines = open(self.FILE_PATH + self.FILE_NAME_16, "rb").readlines()
        assert_equal(len(res.split("\n")), len(lines))
        
    def testGetFileWithTypeFromServer(self):
        res, status = self.fapi.get(self.uri, self.locale, retrievalType='pseudo')
        lines = open(self.FILE_PATH + self.FILE_NAME, "rb").readlines()
        assert_equal(len(res.split("\n")), len(lines))
        
        res, status = self.fapi.get(self.uri16, self.locale, retrievalType='pseudo')
        lines = open(self.FILE_PATH + self.FILE_NAME_16, "rb").readlines()
        assert_equal(len(res.split("\n")), len(lines))

    def testFileDelete(self):
        res, status = self.fapi.list(uriMask="*"+self.uri)
        count_old = res.count('"fileUri":')
        res, status = self.fapi.delete(self.uri)
        assert_equal(True, res.find(self.CODE_SUCCESS_TOKEN) > 0)
        
        res, status = self.fapi.delete(self.uri16)
        assert_equal(True, res.find(self.CODE_SUCCESS_TOKEN) > 0)
 
    def testFileRename(self):
        self.fapi.delete(self.FILE_NAME_NEW)
        res, status = self.fapi.rename(self.uri, self.FILE_NAME_NEW)
        assert_equal(True, res.find(self.CODE_SUCCESS_TOKEN) > 0)
        
        self.fapi.delete(self.FILE_NAME_NEW_16)
        res, status = self.fapi.rename(self.uri16, self.FILE_NAME_NEW_16)
        assert_equal(True, res.find(self.CODE_SUCCESS_TOKEN) > 0)        

    def testLastModified(self):
        resp, status = self.fapi.last_modified(self.uri)
        assert_equal(True, resp.find(self.CODE_SUCCESS_TOKEN) > 0)
        assert_equal(True, len(resp.data.items)>0)

        resp, status = self.fapi.last_modified(self.uri16)
        assert_equal(True, resp.find(self.CODE_SUCCESS_TOKEN) > 0)
        assert_equal(True, len(resp.data.items)>0)




#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import mimetools
import mimetypes
import sys
import urllib
import urllib2


class Callable:
    def __init__(self, anycallable):
        self.__call__ = anycallable


class MultipartPostHandler(urllib2.BaseHandler):
    """ handler for multipart HTTP POST, helper object to provide POST functionality """

    handler_order = urllib2.HTTPHandler.handler_order - 10  # needs to run first
    # Controls how sequences are uncoded. If true, elements may be given multiple values by
    #  assigning a sequence.
    doseq = 1

    def http_request(self, request):
        data = request.get_data()
        if data is not None and type(data) != str:
            v_files = []
            v_vars = []
            try:
                for(key, value) in data.items():
                    if type(value) == file:
                        v_files.append((key, value))
                    else:
                        v_vars.append((key, value))
            except TypeError:
                systype, value, traceback = sys.exc_info()
                raise TypeError("not a valid non-string sequence or mapping object"), traceback

            if len(v_files) == 0:
                data = urllib.urlencode(v_vars, self.doseq)
            else:
                boundary, data = self.multipart_encode(v_vars, v_files)
                contenttype = 'multipart/form-data; boundary=%s' % boundary

                if(request.has_header('Content-Type')
                   and request.get_header('Content-Type').find('multipart/form-data') != 0):
                    print "Replacing %s with %s" % (request.get_header('content-type'), 'multipart/form-data')
                request.add_unredirected_header('Content-Type', contenttype)

            request.add_data(data)
        return request

    def multipart_encode(vars, files, boundary=None, buffer=None):
        if boundary is None:
            boundary = mimetools.choose_boundary()
        if buffer is None:
            buffer = ''
        for(key, value) in vars:
            buffer += '--%s\r\n' % boundary
            buffer += 'Content-Disposition: form-data; name="%s"' % key
            buffer += '\r\n\r\n' + value + '\r\n'
        for(key, fd) in files:
            filename = fd.name.split('/')[-1]
            contenttype = mimetypes.guess_type(filename)[0] or 'application/octet-stream'
            buffer += '--%s\r\n' % boundary
            buffer += 'Content-Disposition: form-data; name="%s"; filename="%s"\r\n' % (key, filename)
            buffer += 'Content-Type: %s\r\n' % contenttype
            fd.seek(0)
            buffer += '\r\n' + fd.read() + '\r\n'
        buffer += '--%s--\r\n\r\n' % boundary
        return boundary, buffer
    multipart_encode = Callable(multipart_encode)

    https_request = http_request



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

#constants for File API

class Params:
    allowedRetrievalTypes = ('pending', 'published', 'pseudo')

    API_KEY    = 'apiKey'
    PROJECT_ID = 'projectId'
    FILE_PATH  = 'file_path'
    FILE_URI   = 'fileUri'
    FILE_TYPE  = 'fileType'
    LOCALE     = 'locale'
    FILE       = 'file'
    APPROVED   = 'approved'
    RETRIEVAL_TYPE = 'retrievalType'
    FILE_URI_NEW   = 'newFileUri'
    CALLBACK_URL    = 'callbackUrl'
    LOCALES_TO_APPROVE = 'localesToApprove'
    LOCALE_IDS = 'localeIds'
    LOCALE_IDS_BRACKET = 'localeIds[]'
    FILE_URIS   = 'fileUris'

class Uri:
    base = '/v1/file/'
    UPLOAD = base + 'upload'
    LIST   = base + 'list'
    GET    = base + 'get'
    STATUS = base + 'status'
    DELETE = base + 'delete'
    RENAME = base + 'rename'
    IMPORT = base + 'import'
    LAST_MODIFIED = base + 'last_modified'

class ReqMethod:
    POST   = "POST"
    GET    = "GET"
    DELETE = "DELETE"



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2013 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

class SmartlingDirective:
    """ Smartling directive which is used for file upload """
    sl_prefix = "smartling."

    def __init__(self, name, value):
        if not name:
            raise Exception("name cannot be empty!")
        self.name = self.__remove_sl_prefix(name.lower())

        if value is None:
            self.value = ""
        else:
            self.value = value

    def __remove_sl_prefix(self, name):
        if name.startswith(self.sl_prefix):
            return name[len(self.sl_prefix):]
        return name



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

#FileApi class implementation

from FileApiBase import FileApiBase


class SmartlingFileApi(FileApiBase):
    """ Wrapper class providing access to all file API commands, all methods below represent API commands.
        Each command returns tuple = (response, status_code) 
        where response is ApiResponse object and status code = HTTP response status code
        
        ApiResponse object is python object as a result of json response parsing
        ApiResponse attributes depend on response json.
        To view all attributes of response use:
        for k,v in response.items(): print k, ':' ,v
        
        Response also can be a string to provide backward compatibility with previous versions
        in case you need json response as a string use :
        api = SmartlingFileApi(host, apiKey, projectId)
        api.response_as_string = True
        
        Some of methods may be called with optional parameters
        like `list` method may have locale optional parameter or offset parameter
        simple list:
             api.list()
        list with additional parameters:
             api.list(locale='es-ES', offset=50)
        """

    def __init__(self, host, apiKey, projectId, proxySettings=None):
        FileApiBase.__init__(self, host, apiKey, projectId, proxySettings)

    def upload(self, uploadData):
        """ implements `upload` api command
            returns (response, status_code) tuple
            for python 2.5 and less commands `upload` and `import_call` returns status_code 0
            for details on `upload` command see  https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/upload%28POST) """
        return self.commandUpload(uploadData)

    def list(self, **kw):
        """ implements `list` api command
            returns (response, status_code) tuple
            for details on `list` command see https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/list%28GET%29 """
        return self.commandList(**kw)

    def get(self, fileUri, locale, **kw):
        """ implements `get` api command
            returns (response, status_code) tuple
            for details on `get` command see https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/list%28GET%29 """
        return self.commandGet(fileUri, locale, **kw)

    def status(self, fileUri, locale, **kw):
        """ implements `status` api command
            returns (response, status_code) tuple
            for details on `status` command see  https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/status%28GET) """
        return self.commandStatus(fileUri, locale, **kw)

    def rename(self, fileUri, newUri, **kw):
        """ implements `rename` api command
            returns (response, status_code) tuple
            for details on `rename` command see  https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/rename%28POST) """
        return self.commandRename(fileUri, newUri, **kw)

    def delete(self, fileUri, **kw):
        """ implements `delete` api command
            returns (response, status_code) tuple
            for details on `delete` command see https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/delete%28DELETE%29 """
        return self.commandDelete(fileUri, **kw)

    def import_call(self, uploadData, locale, **kw):
        """ implements `import` api command
            returns (response, status_code) tuple
            for python 2.5 and less commands `upload` and `import_call` returns status_code 0
            for details on `import` command see https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/import%28POST%29 """
        return self.commandImport(uploadData, locale, **kw)
        
    def last_modified(self, fileUri, locale=None, **kw):
        """ implements `last_modified` api command
            returns (response, status_code) tuple
            for details on `last_modified` command see https://docs.smartling.com/display/docs/Files+API#FilesAPI-/file/last_modified%28GET%29 """
        return self.commandLastModified(fileUri, **kw)
    

class SmartlingFileApiFactory:
    """ Factory class to build SmartlingFileApi objects """
    api_host = 'api.smartling.com'

    def getSmartlingTranslationApi(self, apiKey, projectId, proxySettings=None):
        return SmartlingFileApi(self.api_host, apiKey, projectId, proxySettings)



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

try:
    import json
except ImportError:
    import simplejson24 as json
    
class Data:
    """ provides dictionary items to be object attributes """
    def __init__(self, dict):
        self.dict = dict
        
    def __getattr__(self, key):
        return self.dict[key]
        
    def __str__(self):
        return `self.dict`

class ApiResponse:
    """ response object to store parsed json response as python object, it also behaves like string for backward 
        compatibility with previous SDK versions where response was a string """
    def __init__(self, response_string, status_code):
        self.status_code = status_code
        self.response_string = response_string
        #print status_code, response_string
        self.parse_response(response_string)
        
    def parse_response(self, response_string):
        """ parses json and fills object attributes according json attributes """
        self.response_dict = json.loads(response_string)
        for k, v in self.response_dict['response'].items():
            if k=='data':
                self.data = Data(v)
            else:
                setattr(self, k, v)
    
    def __getattr__(self, key):
        """ provides string object methods to be available for response to behave like a string """
        if hasattr(self.response_dict, key):
            return getattr(self.response_string, key)
            
        try:
            return getattr(self, key)
        except:
            return getattr(self.response_string, key)


#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

class UrlV2Helper:
    
    GET = "/files-api/v2/projects/{projectId}/locales/{localeId}/file"
    GET_MULTIPLE_LOCALES = "/files-api/v2/projects/{projectId}/files/zip"
    GET_ALL_LOCALES_ZIP = "/files-api/v2/projects/{projectId}/locales/all/file/zip"
    GET_ALL_LOCALES_CSV = "/files-api/v2/projects/{projectId}/locales/all/file"
    GET_ORIGINAL = "/files-api/v2/projects/{projectId}/file"
    LIST_FILES = "/files-api/v2/projects/{projectId}/files/list"
    LIST_FILE_TYPES = "/files-api/v2/projects/{projectId}/file-types"
    UPLOAD = "/files-api/v2/projects/{projectId}/file"
    DELETE = "/files-api/v2/projects/{projectId}/file/delete"
    PROJECT_DETAILS = "/projects-api/v2/projects/{projectId}"
    PROJECTS = "/accounts-api/v2/accounts/{accountUid}/projects"
    STATUS_ALL = "/files-api/v2/projects/{projectId}/file/status"
    STATUS_LOCALE = "/files-api/v2/projects/{projectId}/locales/{localeId}/file/status"
    RENAME = "/files-api/v2/projects/{projectId}/file/rename"
    LAST_MODIFIED = "/files-api/v2/projects/{projectId}/locales/{localeId}/file/last-modified"
    LAST_MODIFIED_ALL = "/files-api/v2/projects/{projectId}/file/last-modified"
    IMPORT = "/files-api/v2/projects/{projectId}/locales/{localeId}/file/import"
    LIST_AUTHORIZED_LOCALES = "/files-api/v2/projects/{projectId}/file/authorized-locales"
    AUTHORIZE = "/files-api/v2/projects/{projectId}/file/authorized-locales"
    UNAUTHORIZE = "/files-api/v2/projects/{projectId}/file/authorized-locales"
    GET_TRANSLATIONS = "/files-api/v2/projects/{projectId}/locales/{localeId}/file/get-translations"
    
    def __init__(self, projectId):
        self.projectId = projectId

    def getUrl(self, urlWithPlaceholders, localeId="", accountUid=""):
        url = urlWithPlaceholders.replace("{projectId}", self.projectId)

        if localeId : 
            url = url.replace("{localeId}", localeId)
        
        if accountUid : 
            url = url.replace("{accountUid}", accountUid)
        
        if "{localeId}" in url:
            raise "Unhandled localeId placeholder:" + url
            
        if "{accountUid}" in url:
            raise "Unhandled accountUid placeholder:" + url
            
        return url


#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

#FileApi class implementation

from HttpClient import HttpClient
from MultipartPostHandler import MultipartPostHandler
from Constants import Uri, Params, ReqMethod
from ApiResponse import ApiResponse
from AuthClient import AuthClient
from UrlV2Helper import UrlV2Helper

"""
Upload File - /files-api/v2/projects/{projectId}/file (POST)
Download Original File - /files-api/v2/projects/{projectId}/file (GET)
Download Translated File - Single Locale - /files-api/v2/projects/{projectId}/locales/{localeId}/file (GET)
Download Translated Files - Multiple Locales as .ZIP - /files-api/v2/projects/{projectId}/files/zip (GET)
Download Translated File - All Locales as .ZIP - /files-api/v2/projects/{projectId}/locales/all/file/zip (GET)
Download Translated File - All Locales in one File - CSV - /files-api/v2/projects/{projectId}/locales/all/file (GET)
List Files - /files-api/v2/projects/{projectId}/files/list (GET)
List File Types - /files-api/v2/projects/{projectId}/file-types (GET)
Status - All Locales - /files-api/v2/projects/{projectId}/file/status (GET)
Status - Single Locale / Extended Response - /files-api/v2/projects/{projectId}/locales/{localeId}/file/status (GET)
Rename - /files-api/v2/projects/{projectId}/file/rename (POST)
Delete - /files-api/v2/projects/{projectId}/file/delete (POST)
Last Modified (by locale) - /files-api/v2/projects/{projectId}/locales/{localeId}/file/last-modified (GET)
Last Modified (all locales) - /files-api/v2/projects/{projectId}/file/last-modified (GET)
Import Translations - /files-api/v2/projects/{projectId}/locales/{localeId}/file/import (POST or PUT)
List Authorized Locales - /files-api/v2/projects/{projectId}/file/authorized-locales (GET)
Authorize - /files-api/v2/projects/{projectId}/file/authorized-locales (PUT / POST)
Unauthorize - /files-api/v2/projects/{projectId}/file/authorized-locales (DELETE)
Get Translations - /files-api/v2/projects/{projectId}/locales/{localeId}/file/get-translations (POST)
"""

class FileApiV2:
    """ basic class implementing low-level api calls """
    host = 'api.smartling.com'
    response_as_string = False

    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None):
        self.userIdentifier = userIdentifier
        self.userSecret = userSecret
        self.projectId = projectId
        self.proxySettings = proxySettings
        self.httpClient = HttpClient(self.host, proxySettings)
        self.authClient = AuthClient(userIdentifier, userSecret, proxySettings)
        self.urlHelper = UrlV2Helper(self.projectId)

    def uploadMultipart(self, uri, params, response_as_string=False):
        if params.has_key(Params.FILE_PATH):
            params[Params.FILE] = open(params[Params.FILE_PATH], 'rb')
            del params[Params.FILE_PATH]  # no need in extra field in POST

        authHeader = self.getAuthHeader()  
        response_data, status_code = self.getHttpResponseAndStatus(ReqMethod.POST ,uri, params, MultipartPostHandler, extraHeaders = authHeader)
        response_data = response_data.strip()
        if self.response_as_string or response_as_string:
            return response_data, status_code
        return ApiResponse(response_data, status_code), status_code
  
    def getHttpResponseAndStatus(self, method, uri, params, handler=None, extraHeaders = None):
        return self.httpClient.getHttpResponseAndStatus(method, uri, params, handler, extraHeaders = extraHeaders)
  
    def getAuthHeader(self):
        token = self.authClient.getToken()
        if token is None:
            raise "Error getting token"
            
        return {"Authorization" : "Bearer "+ token} 
   
    def command_raw(self, method, uri, params):
        authHeader = self.getAuthHeader()
        return self.getHttpResponseAndStatus(method, uri, params, extraHeaders = authHeader)

    def command(self, method, uri, params):
        data, code = self.command_raw(method, uri, params)
        if self.response_as_string:
            return data, code
        return  ApiResponse(data, code), code


#-----------------------------------------------------------------------------------

    def commandGet(self, fileUri, locale, **kw):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/Single-Locale/ """
        kw[Params.FILE_URI] = fileUri
 
        if Params.RETRIEVAL_TYPE in kw and not kw[Params.RETRIEVAL_TYPE] in Params.allowedRetrievalTypes:
            raise "Not allowed value `%s` for parameter:%s try one of %s" % (kw[Params.RETRIEVAL_TYPE],
                                                                             Params.RETRIEVAL_TYPE,
                                                                             Params.allowedRetrievalTypes)
        url = self.urlHelper.getUrl(self.urlHelper.GET, localeId=locale)
        return self.command_raw(ReqMethod.GET, url, kw)


    def commandGetMultipleLocalesAsZip(self, fileUri, localeIds, **kw):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/Multiple-Locales/ """
        kw[Params.FILE_URIS] = fileUri
        kw[Params.LOCALE_IDS] = localeIds
 
        if Params.RETRIEVAL_TYPE in kw and not kw[Params.RETRIEVAL_TYPE] in Params.allowedRetrievalTypes:
            raise "Not allowed value `%s` for parameter:%s try one of %s" % (kw[Params.RETRIEVAL_TYPE],
                                                                             Params.RETRIEVAL_TYPE,
                                                                             Params.allowedRetrievalTypes)
        
        
        return self.command_raw(ReqMethod.GET, self.urlHelper.getUrl(self.urlHelper.GET_MULTIPLE_LOCALES), kw)

 
 
 
    def commandGetAllLocalesZip(self, fileUri, **kw):
         """ http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/All-Locales """
         kw[Params.FILE_URI] = fileUri
  
         if Params.RETRIEVAL_TYPE in kw and not kw[Params.RETRIEVAL_TYPE] in Params.allowedRetrievalTypes:
             raise "Not allowed value `%s` for parameter:%s try one of %s" % (kw[Params.RETRIEVAL_TYPE],
                                                                              Params.RETRIEVAL_TYPE,
                                                                              Params.allowedRetrievalTypes)

         url = self.urlHelper.getUrl(self.urlHelper.GET_ALL_LOCALES_ZIP)
         
         return self.command_raw(ReqMethod.GET, url, kw)
        

    def commandGetAllLocalesCsv(self, fileUri, **kw):
         """  http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/All-Locales-CSV """
         kw[Params.FILE_URI] = fileUri
  
         if Params.RETRIEVAL_TYPE in kw and not kw[Params.RETRIEVAL_TYPE] in Params.allowedRetrievalTypes:
             raise "Not allowed value `%s` for parameter:%s try one of %s" % (kw[Params.RETRIEVAL_TYPE],
                                                                              Params.RETRIEVAL_TYPE,
                                                                              Params.allowedRetrievalTypes)

         url = self.urlHelper.getUrl(self.urlHelper.GET_ALL_LOCALES_CSV)
         return self.command_raw(ReqMethod.GET, url, kw)


    def commandGetOriginal(self, fileUri):
         """  http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/Original-File/ """
         kw = {}
         kw[Params.FILE_URI] = fileUri
  
         url = self.urlHelper.getUrl(self.urlHelper.GET_ORIGINAL)
         return self.command_raw(ReqMethod.GET, url, kw)            

    def commandList(self, **kw):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/List/ """
        url = self.urlHelper.getUrl(self.urlHelper.LIST_FILES)
        return self.command(ReqMethod.GET, url, kw)
        
    def commandListFileTypes(self, **kw):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/List-File-Types/ """
        return self.command(ReqMethod.GET, self.urlHelper.getUrl(self.urlHelper.LIST_FILE_TYPES), kw)


    def commandUpload(self, filePath, fileType, **kw):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Upload-File/ """
        params = {
                Params.FILE_URI: filePath,
                Params.FILE_TYPE: fileType,
                Params.FILE_PATH: filePath
            }

        for k,v in kw.items():
            params[k] = v

        if params.has_key("SmartlingDirectives"):
            directives = kw["SmartlingDirectives"]
            del params["SmartlingDirectives"]
            if type(directives) != type([]) and type(directives) != type(()):
                directives = [directives]
            for directive in directives:
               params[directive.sl_prefix + directive.name] = directive.value
        
        url = self.urlHelper.getUrl(self.urlHelper.UPLOAD)
        return self.uploadMultipart(url, params)
        
    def commandProjectDetails(self):    
        """ http://docs.smartling.com/pages/API/v2/Projects/Project-Details/ """
        kw = {}
        url = self.urlHelper.getUrl(self.urlHelper.PROJECT_DETAILS)
        return self.command(ReqMethod.GET, url, kw)
        
    def commandProjects(self, accountUid):    
        """ http://docs.smartling.com/pages/API/v2/Projects/List-Projects/ """
        kw = {}
        url = self.urlHelper.getUrl(self.urlHelper.PROJECTS, accountUid = accountUid)
        return self.command(ReqMethod.GET, url, kw)
        

    def commandDelete(self, fileUri, **kw):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Delete/ """
        kw[Params.FILE_URI] = fileUri
        uri = self.urlHelper.getUrl(self.urlHelper.DELETE)

        return self.command(ReqMethod.POST, uri, kw)
        
    def commandStatus(self, fileUri):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Status/All-Locales/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.STATUS_ALL)
        return self.command(ReqMethod.GET, url, kw)
        
    def commandStatusLocale(self, fileUri, localeId):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Status/Single-Locale/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.STATUS_LOCALE, localeId = localeId)
        return self.command(ReqMethod.GET, url, kw)     
            
    def commandRename(self, fileUri, newFileUrl):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Rename/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        kw[Params.FILE_URI_NEW] = newFileUrl
        url = self.urlHelper.getUrl(self.urlHelper.RENAME)
        return self.command(ReqMethod.POST, url, kw)

    def commandLastModified(self, fileUri, localeId, **kw):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Last-Modified/Single-Locale/ """
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.LAST_MODIFIED, localeId = localeId)
        return self.command(ReqMethod.GET, url, kw) 

    def commandLastModifiedAll(self, fileUri, **kw):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Last-Modified/All-Locales/ """
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.LAST_MODIFIED_ALL)
        return self.command(ReqMethod.GET, url, kw) 

    def commandImport(self, filePathOriginal, filePathTranslated, fileType, localeId, **kw):
        params = {}
        params[Params.FILE_URI]  = filePathOriginal
        params[Params.FILE_TYPE] = fileType
        params[Params.FILE_PATH] = filePathTranslated
        params["file"] = filePathTranslated + ";type=text/plain"

        for k,v in kw.items():
            params[k] = v
        
        url = self.urlHelper.getUrl(self.urlHelper.IMPORT, localeId = localeId)
        return self.uploadMultipart(url, params)

    def commandListAuthorizedLocales(self, fileUri):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/List-Authorized-Locales/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        url = self.urlHelper.getUrl(self.urlHelper.LIST_AUTHORIZED_LOCALES)
        return self.command(ReqMethod.GET, url, kw) 

    def commandAuthorize(self, fileUri, localeIds):
        """ http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/Authorize/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        kw[Params.LOCALE_IDS_BRACKET] = ",".join(localeIds)
        url = self.urlHelper.getUrl(self.urlHelper.AUTHORIZE)
        return self.command(ReqMethod.POST, url, kw)
        
    def commandUnauthorize(self, fileUri, localeIds):
        """  http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/Unauthorize/ """
        kw = {}
        kw[Params.FILE_URI] = fileUri
        kw[Params.LOCALE_IDS_BRACKET] = ",".join(localeIds)
        url = self.urlHelper.getUrl(self.urlHelper.UNAUTHORIZE)
        return self.command(ReqMethod.DELETE, url, kw)
        
    def commandGetTranslations(self, fileUri, filePath, localeId, **kw):
        """  http://docs.smartling.com/pages/API/v2/FileAPI/Get-Translations/ """
        kw[Params.FILE_URI]  = fileUri
        kw[Params.FILE_PATH] = filePath
        kw["file"] = filePath + ";type=text/plain"

        url = self.urlHelper.getUrl(self.urlHelper.GET_TRANSLATIONS, localeId = localeId)
        return self.uploadMultipart(url, kw, response_as_string=True)       
       


#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys
import time
import zipfile
import StringIO
from datetime import date

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApiSdk.SmartlingFileApiV2 import SmartlingFileApiV2
from smartlingApiSdk.ProxySettings import ProxySettings
from nose.tools import assert_equal
from smartlingApiSdk.version import version
from smartlingApiSdk.Credentials import Credentials

class testFapiV2(object):

    FILE_NAME = "java.properties"
    FILE_NAME_16 = "javaUTF16.properties"
    FILE_TYPE = "javaProperties"
    FILE_TYPE_CSV = "csv"
    FILE_PATH = "../resources/"
    FILE_NAME_NEW = "java.properties.renamed"
    FILE_NAME_NEW_16 = "javaUTF16.properties.renamed"
    FILE_NAME_CSV = "test.csv"
    
    FILE_NAME_IMPORT_ORIG = "test_import.xml"
    FILE_NAME_IMPORT_TRANSLATED = "test_import_es.xml"
    FILE_TYPE_IMPORT = "android"

    CALLBACK_URL = "http://google.com/?q=hello"

    CODE_SUCCESS_TOKEN = 'SUCCESS'
            

    def setUp(self):
        credentials = Credentials() #Gets your Smartling credetnials from environment variables
        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID
        self.MY_LOCALE = credentials.MY_LOCALE
        
        #needed for testProjects
        self.MY_ACCOUNT_UID = credentials.MY_ACCOUNT_UID
    
        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None        
        self.fapi = SmartlingFileApiV2(self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings)
        unique_suffix = "_" + version + "_" + `time.time()`
        self.uri = self.FILE_NAME + unique_suffix 
        self.doUpload(self.FILE_NAME, self.uri, self.FILE_TYPE)
        
        self.uri_csv = self.FILE_NAME_CSV + unique_suffix

        self.uri16 = self.FILE_NAME_16 + unique_suffix 
        self.doUpload(self.FILE_NAME_16, self.uri16, self.FILE_TYPE)
        
        self.uri_to_rename = self.FILE_NAME_NEW + unique_suffix
        self.uri_import = self.FILE_NAME_IMPORT_ORIG + unique_suffix
        
        print "setUp", "OK", "\n\n\n"


    def tearDown(self):
        res, status = self.fapi.delete(self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        
        res, status = self.fapi.delete(self.uri16)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        
        print "tearDown", "OK"

    def doUpload(self, name, uri, type):
        #ensure file is uploaded which is necessary for all tests
        uniqueUriForUploadTestFile = uri
        localeIdsToAuthorize = [self.MY_LOCALE]
        res, status = self.fapi.upload(self.FILE_PATH + name, type, fileUri = uniqueUriForUploadTestFile, localeIdsToAuthorize = localeIdsToAuthorize )
        
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        print status, res
        return res, status
        
    def testFileList(self):
        res, status = self.fapi.list()
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        uris = map(lambda x:x['fileUri'], res.data.items)

        assert_equal(True, self.uri in uris)
        assert_equal(True, self.uri16 in uris)
        
        print "testFileList", "OK"

    def testFileListTypes(self):
        res, status = self.fapi.list_file_types()
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        print "testFileListTypes", "OK"
        
    def testGet(self):
        res, status = self.fapi.get(self.uri, self.MY_LOCALE)
        assert_equal(200, status)
        
        resp_lines_count = len(res.split("\n"))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME, "rb").readlines() )
        assert_equal(resp_lines_count, file_lines_count)
        
        print "testGet", "OK"
    
        res, status = self.fapi.get(self.uri16, self.MY_LOCALE)
        assert_equal(200, status)

        resp_lines_count = len(res.split("\n"))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME_16, "rb").readlines() )
        assert_equal(resp_lines_count, file_lines_count)
        print "testGet Utf16", "OK"
        
        
    def testGetMultipleLocalesAsZip(self):
        res, status = self.fapi.get_multiple_locales([self.uri,self.uri16], [self.MY_LOCALE])
        assert_equal(200, status)
        
        zfile = zipfile.ZipFile(StringIO.StringIO(res))
        names = zfile.namelist()
        
        assert_equal(True, self.MY_LOCALE+"/"+self.uri in names)
        assert_equal(True, self.MY_LOCALE+"/"+self.uri16 in names)
        
        print "testGetMultipleLocalesAsZip", "OK"


    def testGetAllLocalesZip(self):
        res, status = self.fapi.get_all_locales(self.uri)
        assert_equal(200, status)
        
        zfile = zipfile.ZipFile(StringIO.StringIO(res))
        names = zfile.namelist()
        
        assert_equal(True, self.MY_LOCALE+"/"+self.uri in names)
        
        print "testGetAllLocalesZip", "OK"


    def testGetOriginal(self):
        res, status = self.fapi.get_original(self.uri)
        assert_equal(200, status)
        
        orig = open(self.FILE_PATH + self.FILE_NAME, "r").read()
        assert_equal(res, orig)
        
        print "testGetOriginal", "OK"
    
        res, status = self.fapi.get_original(self.uri16)
        assert_equal(200, status)

        resp_lines_count = len(res.split("\n"))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME_16, "rb").readlines() )
        assert_equal(resp_lines_count, file_lines_count)
        print "testGetOriginal Utf16", "OK"        


    def testGetAllLocalesCsv(self):
        self.doUpload(self.FILE_NAME_CSV, self.uri_csv, self.FILE_TYPE_CSV)
        res, status = self.fapi.get_all_locales_csv(self.uri_csv)
        assert_equal(200, status)

        res, status = self.fapi.delete(self.uri_csv)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        print "testGetAllLocalesCsv", "OK"

    def testProjects(self):
        if self.MY_ACCOUNT_UID == "CHANGE_ME":
            print "can't test projects api call, set self.MY_ACCOUNT_UID or export SL_ACCOUNT_UID=*********"
            return
        res, status = self.fapi.projects(self.MY_ACCOUNT_UID)
        
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        
        projects = map(lambda x:x['projectId'], res.data.items)

        assert_equal(True, self.MY_PROJECT_ID in projects)
        print "testProjects", "OK"

    def testProjectDetails(self):
        res, status = self.fapi.project_details()
        
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        assert_equal(self.MY_PROJECT_ID, res.data.projectId)
        
        print "testProjectDetails", "OK"

    def testStatus(self):
        res, status = self.fapi.status(self.uri)
        
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        assert_equal(res.data.fileUri, self.uri)
        assert_equal(True, len(res.data.items) > 0)
        
        print "testStatus", "OK"


    def testStatusLocale(self):
        res, status = self.fapi.status_locale(self.uri, self.MY_LOCALE)
        
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        assert_equal(res.data.fileUri, self.uri)
        assert_equal(res.data.fileType, self.FILE_TYPE)
        
        print "testStatusLocale", "OK"

    def testFileRename(self):
    
        res, status = self.fapi.rename(self.uri, self.uri_to_rename)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        
        #rename it back so tearDown could remove it
        res, status = self.fapi.rename(self.uri_to_rename, self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        
        print "testStatusLocale", "OK"
         
    def testLastModified(self):
        resp, status = self.fapi.last_modified(self.uri, self.MY_LOCALE)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)

        lm_date = resp.data.lastModified[:10]
        assert_equal(lm_date,  date.today().isoformat())

        resp, status = self.fapi.last_modified(self.uri16, self.MY_LOCALE)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)

        lm_date = resp.data.lastModified[:10]
        assert_equal(lm_date,  date.today().isoformat())

        print "testLastModified", "OK"
        
    def testLastModifiedAll(self):
        resp, status = self.fapi.last_modified_all(self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)
        assert_equal(True, resp.data.items > 0)

        resp, status = self.fapi.last_modified_all(self.uri16)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)
        assert_equal(True, resp.data.items > 0)

        print "testLastModifiedAll", "OK"        
        
    def testImport(self):
        res, status = self.fapi.upload(self.FILE_PATH + self.FILE_NAME_IMPORT_ORIG, self.FILE_TYPE_IMPORT , fileUri=self.uri_import)

        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        
        originalPath = self.FILE_PATH + self.FILE_NAME_IMPORT_ORIG
        translatedPath = self.FILE_PATH + self.FILE_NAME_IMPORT_TRANSLATED
    
        resp, status = self.fapi.import_call(originalPath, translatedPath, 
            self.FILE_TYPE_IMPORT, self.MY_LOCALE, 
            fileUri=self.uri_import, translationState="PUBLISHED")
            
        assert_equal(resp.code, self.CODE_SUCCESS_TOKEN)
        assert_equal(resp.data.wordCount, 2)
        assert_equal(resp.data.stringCount, 2)
        assert_equal(resp.data.translationImportErrors, [])

        res, status = self.fapi.delete(self.uri_import)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)

        print "testImport", "OK"  
        
    def testListAuthorizedLocales(self):
        resp, status = self.fapi.last_modified_all(self.uri)
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, resp.code)
        assert_equal(True, resp.data.items > 0)

        locales = map(lambda x:x['localeId'], resp.data.items)
        assert_equal(True, self.MY_LOCALE in locales)
        print "testListAuthorizedLocales", "OK" 
    
    
    def testAuthorize(self):
        res, status = self.fapi.authorize(self.uri, [self.MY_LOCALE, 'uk-UA'])
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        
        print "testAuthorize", "OK" 
        
    def testUnauthorize(self):
        res, status = self.fapi.unauthorize(self.uri, [self.MY_LOCALE, 'uk-UA'])
        assert_equal(200, status)
        assert_equal(self.CODE_SUCCESS_TOKEN, res.code)
        
        print "testUnauthorize", "OK" 
        

    def testGetTranslations(self):        
        res, status = self.fapi.get_translations(self.uri, self.FILE_PATH+self.FILE_NAME, (self.MY_LOCALE))
        
        assert_equal(200, status)
        
        resp_lines_count = len(res.split("\n"))
        file_lines_count = len( open(self.FILE_PATH + self.FILE_NAME, "rb").readlines() )
        assert_equal(resp_lines_count, file_lines_count)
        
        print "testUnauthorize", "OK" 
        


#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys
lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApiSdk.SmartlingFileApiV2 import SmartlingFileApiV2
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.SmartlingDirective import SmartlingDirective
from smartlingApiSdk.Credentials import Credentials

class SmartlingApiExample:

    def __init__(self, file_name, file_type, new_name):
        credentials = Credentials() #Gets your Smartling credetnials from environment variables

        self.MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
        self.MY_USER_SECRET = credentials.MY_USER_SECRET
        self.MY_PROJECT_ID = credentials.MY_PROJECT_ID
        self.MY_LOCALE = credentials.MY_LOCALE

        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port")
        else:
            proxySettings = None

        self.fapi = SmartlingFileApiV2( self.MY_USER_IDENTIFIER, self.MY_USER_SECRET, self.MY_PROJECT_ID, proxySettings)
        self.file_type = file_type
        self.file_name = file_name
        self.new_name = new_name
        
    def printMarker(self, caption):
        print "--" + caption + "-" * 40

    def test_import(self, name_to_import):
        """ this method tests `import` command """
        self.printMarker("file upload")
        #upload file first to be able upload it's translations later
        
        path = FILE_PATH + self.file_name
        resp, code = self.fapi.upload(path, self.file_type)
        if 200!=code:
            raise "failed"
   
        print resp, code
    
        self.printMarker("files list")
        #list all files to ensure upload worked
        resp, code = self.fapi.list()
        print resp, code

        self.printMarker("importing uploaded")
        #set correct uri/name for file to be imported
        path_to_import = FILE_PATH + name_to_import

        #import translations from file
        resp, code = self.fapi.import_call(path, path_to_import, 
                    self.file_type, self.MY_LOCALE, 
                     translationState="PUBLISHED")
        print resp, code

        if 200!=code:
            raise "failed"

        #perform `last_modified` command
        self.printMarker("last modified")
        resp, code = self.fapi.last_modified(path, self.MY_LOCALE)
        print "resp.code=", resp.code
        print "resp.data", resp.data
        
        self.printMarker("delete from server goes here")
        #delete test file imported in the beginning of test
        resp, code = self.fapi.delete(path)
        print resp, code

    def test(self):
        """ simple illustration for set of API commands: upload, list, status, get, rename, delete """
        self.printMarker("file upload")
        path = FILE_PATH + self.file_name
        directives=[SmartlingDirective("placeholder_format_custom", "\[.+?\]")]
        resp, code = self.fapi.upload(path, self.file_type, authorize="true", callbackUrl=CALLBACK_URL, SmartlingDirectives=directives)
        print resp, code
        if 200!=code:
            raise "failed"

        self.printMarker("files list")
        resp, code = self.fapi.list()
        print resp, code

        self.printMarker("file status")
        resp, code = self.fapi.status(path)
        print resp, code

        self.printMarker("file from server goes here")
        resp, code = self.fapi.get(path, self.MY_LOCALE)
        print resp, code

        self.printMarker("renaming file")
        resp, code = self.fapi.rename(path, self.new_name)
        print resp, code

        self.printMarker("delete from server goes here")
        resp, code = self.fapi.delete(self.new_name)
        print resp, code

        self.printMarker("doing list again to see if it's deleted")
        resp, code = self.fapi.list()
        print resp, code


FILE_NAME = "java.properties"
FILE_NAME_UTF16 = "javaUTF16.properties"
FILE_TYPE = "javaProperties"
FILE_PATH = "../resources/"
FILE_NAME_RENAMED = "java.properties.renamed"
CALLBACK_URL = "http://yourdomain.com/callback"


FILE_NAME_IMPORT = "test_import.xml"
FILE_NAME_TO_IMPORT = "test_import_es.xml"
FILE_TYPE_IMPORT ="android"

def upload_test():
    #test simple file
    example = SmartlingApiExample(FILE_NAME, FILE_TYPE, FILE_NAME_RENAMED)
    example.test()

def import_test():
    #example for import and last_modified commands
    example = SmartlingApiExample(FILE_NAME_IMPORT, FILE_TYPE_IMPORT, FILE_NAME_RENAMED)
    example.test_import(FILE_NAME_TO_IMPORT)

upload_test()
import_test()



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012-2016 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import urllib, urllib2
import sys
from Constants import ReqMethod

from MultipartPostHandler import MultipartPostHandler
from version import version

class HttpClient:
    headers = {"Content-Type": "application/x-www-form-urlencoded", "User-Agent":"Python SDK client v"+ version}
    protocol = 'https://'
    
    def __init__(self, host, proxySettings=None):
       self.host = host
       self.proxySettings = proxySettings

    def getHttpResponseAndStatus(self, method, uri, params, handler=None, extraHeaders = {}, requestBody=""):
        if self.proxySettings:
            if self.proxySettings.username:
                proxy_str = 'http://%s:%s@%s:%s' % (self.proxySettings.username, self.proxySettings.passwd, self.proxySettings.host, self.proxySettings.port)
            else: 
                proxy_str = 'http://%s:%s' % (self.proxySettings.host, self.proxySettings.port)

            opener = urllib2.build_opener(
                handler or urllib2.HTTPHandler(),
                handler or urllib2.HTTPSHandler(),
                urllib2.ProxyHandler({"https": proxy_str}))
            urllib2.install_opener(opener)
        elif handler:
            opener = urllib2.build_opener(MultipartPostHandler)
            urllib2.install_opener(opener)
        
        if not handler:
            params = self.encodeParametersAsString(params)
        else:
            prarms = self.encodeListParams(params)
        
        headers = {}
        for k,v in self.headers.items():
            headers[k] = v

        for k,v in extraHeaders.items():
            headers[k] = v
        
        url = self.protocol + self.host + uri
        if method in (ReqMethod.GET, ReqMethod.DELETE) and params: url += "?" + params
        req = urllib2.Request(url, params, headers=headers)
        req.get_method = lambda: method

        try:
            if requestBody:
                response = urllib2.urlopen(req, requestBody)
            else:
                response = urllib2.urlopen(req)
        except urllib2.HTTPError, e:
            response = e
        if sys.version_info[:2] >= (2,6):
            status_code = response.getcode() 
        else:
            status_code = response.code
            
        response_data = response.read()
        if 200!=status_code:
            print "Non 200 response:",url, status_code, "response=", response_data
        return response_data, status_code

    def encodeParametersAsString(self, params):
        #processes lits parameters separately i.e. {key:[v1, v2]} is encoded as 'key[]=v1&key[]=v2'
        result = ""
        for k, v in params.items():
            if type(v) == type([]) or type(v) == type(()):
                del params[k]
                for single in v:
                    if len(result)>0:
                        result += "&"
                    key_list = k+"[]"
                    dct = {key_list: single} 
                    result += urllib.urlencode( dct )

        if params:    
            if len(result)>0:
                result += "&"

            result +=  urllib.urlencode(params)

        return result

    def encodeListParams(self, params):
         for k, v in params.items():
            if type(v) == type([]) or type(v) == type(()):
                del params[k]
                params[k + '[]'] = ",".join(v)



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

from HttpClient import HttpClient
from ApiResponse import ApiResponse
import time
from Constants import ReqMethod
import pdb
class AuthClient:
    host = "api.smartling.com"
    authUri = "/auth-api/v2/authenticate"
    refreshUri = "/auth-api/v2/authenticate/refresh"
    timeJitter = 5 #seconds off server expires time

    def __init__(self, userIdentifier, userSecret, proxySettings=None):
        self.httpClient = HttpClient(self.host, proxySettings)
        self.userIdentifier = userIdentifier
        self.userSecret = userSecret
        
    def request(self, uri, body):
        header = {"Content-Type": "application/json"}
        response_data, status_code = self.httpClient.getHttpResponseAndStatus(ReqMethod.POST, uri, params={}, extraHeaders=header, requestBody=body)
        apiResponse = ApiResponse(response_data, status_code)
        
        now = time.time()
        try:
            self.accessToken = apiResponse.data.accessToken
            self.refreshToken = apiResponse.data.refreshToken
            self.accessExpiresAt = now + apiResponse.data.expiresIn - self.timeJitter
            self.refreshExpiresAt = now + apiResponse.data.refreshExpiresIn - self.timeJitter
        except Exception, e:
            print e
            self.accessToken = None
        
    def authenticate(self):
        body = '{"userIdentifier": "%s", "userSecret": "%s"}' % (self.userIdentifier, self.userSecret)
        self.request(self.authUri, body)
        
    def refresh(self):
        body = '{"refreshToken":"%s"}' % self.refreshToken 
        self.request(self.refreshUri, body)
        
    def getToken(self):
        if not hasattr(self,'accessToken'):
            self.authenticate()
        
        now = time.time()
        if now >= self.accessExpiresAt:
            if now >= self.refreshExpiresAt:
               self.refresh()
            else:
                self.authenticate()
        return self.accessToken 



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

#FileApi class implementation

from HttpClient import HttpClient
from MultipartPostHandler import MultipartPostHandler
from Constants import Uri, Params, ReqMethod
from ApiResponse import ApiResponse

class FileApiBase:
    """ basic class implementing low-level api calls """
    response_as_string = False

    def __init__(self, host, apiKey, projectId, proxySettings=None):
        self.host = host
        self.apiKey = apiKey
        self.projectId = projectId
        self.proxySettings = proxySettings
        self.httpClient = HttpClient(host, proxySettings)

    def addApiKeys(self, params):
        params[Params.API_KEY] = self.apiKey
        params[Params.PROJECT_ID] = self.projectId

    def uploadMultipart(self, uri, params):
        self.addApiKeys(params)
        params[Params.FILE] = open(params[Params.FILE_PATH], 'rb')
        del params[Params.FILE_PATH]  # no need in extra field in POST
        response_data, status_code = self.getHttpResponseAndStatus( ReqMethod.POST, uri, params, MultipartPostHandler)
        response_data = response_data.strip()
        if self.response_as_string:
            return response_data, status_code
        return ApiResponse(response_data, status_code), status_code
  
    def getHttpResponseAndStatus(self, method, uri, params, handler=None):
        return self.httpClient.getHttpResponseAndStatus(method, uri, params, handler)
  
    def command_raw(self, method, uri, params):
        self.addApiKeys(params)
        return self.getHttpResponseAndStatus(method, uri, params)

    def command(self, method, uri, params):
        data, code = self.command_raw(method, uri, params)
        if self.response_as_string:
            return data, code
        return  ApiResponse(data, code), code

    # commands

    def commandUpload(self, uploadData):
        params = {
                    Params.FILE_URI: uploadData.uri or uploadData.name,
                    Params.FILE_TYPE: uploadData.type,
                    Params.FILE_PATH: uploadData.path + uploadData.name
                  }
        if (uploadData.approveContent):
            params[Params.APPROVED] = uploadData.approveContent

        if (uploadData.callbackUrl):
            params[Params.CALLBACK_URL] = uploadData.callbackUrl

        if (uploadData.directives):
            for index, directive in enumerate(uploadData.directives):
                params[directive.sl_prefix + directive.name] = directive.value
                
        if (uploadData.localesToApprove):
            for index, locale in enumerate(uploadData.localesToApprove):
                params['{0}[{1}]'.format(Params.LOCALES_TO_APPROVE, index)] = locale

        return self.uploadMultipart(Uri.UPLOAD, params)

    def commandList(self, **kw):
        return self.command(ReqMethod.POST, Uri.LIST, kw)

    def commandLastModified(self, fileUri, locale=None, **kw):
        kw[Params.FILE_URI] = fileUri
        if locale is not None:
            kw[Params.LOCALE] = locale
        return self.command(ReqMethod.GET, Uri.LAST_MODIFIED, kw)
        
    def commandGet(self, fileUri, locale, **kw):
        kw[Params.FILE_URI] = fileUri
        kw[Params.LOCALE] = locale
        if Params.RETRIEVAL_TYPE in kw and not kw[Params.RETRIEVAL_TYPE] in Params.allowedRetrievalTypes:
            raise "Not allowed value `%s` for parameter:%s try one of %s" % (kw[Params.RETRIEVAL_TYPE],
                                                                             Params.RETRIEVAL_TYPE,
                                                                             Params.allowedRetrievalTypes)

        return self.command_raw(ReqMethod.POST, Uri.GET, kw)

    def commandDelete(self, fileUri, **kw):
        kw[Params.FILE_URI] = fileUri

        return self.command(ReqMethod.POST, Uri.DELETE, kw)
        
    def commandImport(self, uploadData, locale, **kw):
        kw[Params.FILE_URI]  = uploadData.uri
        kw[Params.FILE_TYPE] = uploadData.type
        kw[Params.FILE_PATH] = uploadData.path + uploadData.name
        kw["file"] = uploadData.path + uploadData.name + ";type=text/plain"
        kw[Params.LOCALE] = locale
        self.addApiKeys(kw)

        return self.uploadMultipart(Uri.IMPORT, kw)

    def commandStatus(self, fileUri, locale, **kw):
        kw[Params.FILE_URI] = fileUri
        kw[Params.LOCALE] = locale

        return self.command(ReqMethod.POST, Uri.STATUS, kw)

    def commandRename(self, fileUri, newUri, **kw):
        kw[Params.FILE_URI] = fileUri
        kw[Params.FILE_URI_NEW] = newUri

        return self.command(ReqMethod.POST, Uri.RENAME, kw)



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2013 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys

lib_path = os.path.abspath('../')
sys.path.append(lib_path)

from smartlingApiSdk.ApiResponse import ApiResponse
from nose.tools import assert_equal


class test_ApiResponse(object):
    JSON_STATUS = '{"response":{"data":{"fileUri":"javaUTF16.properties","wordCount":4,"fileType":"javaProperties","callbackUrl":"http://yourdomain.com/callback","lastUploaded":"2014-06-10T12:29:17","stringCount":4,"approvedStringCount":4,"completedStringCount":0},"code":"SUCCESS","messages":[]}}'
    def test_init(self):
        pass
        
    def test_ApiResponse_status(self):
        ar = ApiResponse(self.JSON_STATUS, "200")

        assert_equal(ar.status_code, "200")
        assert_equal(ar.code, "SUCCESS")
        assert_equal(ar.messages, [])

        assert_equal(ar.data.lastUploaded, '2014-06-10T12:29:17')
        assert_equal(ar.data.fileType, 'javaProperties')
        assert_equal(ar.data.stringCount, 4)
        assert_equal(ar.data.wordCount, 4)
        assert_equal(ar.data.approvedStringCount, 4)
        assert_equal(ar.data.fileUri, 'javaUTF16.properties')
        assert_equal(ar.data.completedStringCount, 0)
        assert_equal(ar.data.callbackUrl, 'http://yourdomain.com/callback')



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

#properties for upload


class UploadData:
    """ Helper class to store `upload` and `import` command attributes """
    approveContent = "false"
    callbackUrl = ""
    localesToApprove = []

    def __init__(self, path, name, type):
        self.path = path
        self.name = name
        self.type = type
        self.uri  = name
        self.directives = []
 
    def setApproveContent(self, approveContent):
        self.approveContent = approveContent

    def setCallbackUrl(self, callbackUrl):
        self.callbackUrl = callbackUrl
        
    def setLocalesToApprove(self, localesToApprove):
        self.localesToApprove = localesToApprove

    def addDirective(self, directive):
        self.directives.append(directive)

    def setUri(self, uri):
        self.uri = uri



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

#FileApi class implementation

from FileApiV2 import FileApiV2

class SmartlingFileApiV2(FileApiV2):
    """ Wrapper class providing access to all file API commands, all methods below represent API commands.
        Each command returns tuple = (response, status_code) 
        where response is ApiResponse object and status code = HTTP response status code
        
        ApiResponse object is python object as a result of json response parsing
        ApiResponse attributes depend on response json.
        To view all attributes of response use:
        for k,v in response.items(): print k, ':' ,v
        
        Response also can be a string to provide backward compatibility with previous versions
        in case you need json response as a string use :
        api = SmartlingFileApi(userIdentifier, userSecret, projectId)
        api.response_as_string = True
        
        Some of methods may be called with optional parameters
        like `list` method may have locale optional parameter or offset parameter
        simple list:
             api.list()
        list with additional parameters:
             api.list(limit=100, offset=50)
        """
        
    def __init__(self, userIdentifier, userSecret, projectId, proxySettings=None):
        FileApiV2.__init__(self, userIdentifier, userSecret, projectId, proxySettings)


    def projects(self, accountUid):
        """
        Returns a list of all projects in an account, including basic project details.
        returns (response, status_code) tuple
        http://docs.smartling.com/pages/API/v2/Projects/List-Projects/
        """
        return self.commandProjects(accountUid)


    def project_details(self):
        """
        Returns basic details on a specific Smartling project.
        returns (response, status_code) tuple
        for details see http://docs.smartling.com/pages/API/v2/Projects/Project-Details/
        """
        return self.commandProjectDetails()



    def upload(self, filePath, fileType, **kw):
        """ Uploads original source content to Smartling
            returns (response, status_code) tuple
            for details on `upload` command see http://docs.smartling.com/pages/API/v2/FileAPI/Upload-File/ """
        return self.commandUpload(filePath, fileType, **kw)

    def get(self, fileUri, locale, **kw):
        """ implements `get` api command
            returns (response, status_code) tuple where response is file for specific locale
            for details on `get` command see http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/Single-Locale/ """
        return self.commandGet(fileUri, locale, **kw)
        
    def get_multiple_locales(self, fileUri, localeIds, **kw):   
        """ downloads multiple locales of file(s) as zip
            returns (response, status_code) tuple where response is zip file
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/Multiple-Locales/ """
        return self.commandGetMultipleLocalesAsZip(fileUri, localeIds, **kw)
        
    def get_all_locales(self, fileUri, **kw):
        """ downloads all locales of file as zip
            returns (response, status_code) tuple where response is zip file
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/All-Locales/ """
        return self.commandGetAllLocalesZip(fileUri, **kw)
        
    def get_all_locales_csv(self, fileUri, **kw):
        """ downloads all translations for the requested file in a single CSV file
            returns (response, status_code) tuple where response is csv file
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/All-Locales-CSV/ """
        return self.commandGetAllLocalesCsv(fileUri, **kw)      

    def get_original(self, fileUri):
        """ downloads the original version of the requested file from Smartling
            returns (response, status_code) tuple where response is csv file
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Download-File/Original-File/ """
        return self.commandGetOriginal(fileUri) 

    def list(self, **kw):
        """ implements `list` api command
            returns (response, status_code) tuple
            for details on `list` http://docs.smartling.com/pages/API/v2/FileAPI/List/ """
        return self.commandList(**kw)
        
    def list_file_types(self, **kw):
        """ Returns a list of all file types currently represented in the project.
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/List-File-Types/ """
        return self.commandListFileTypes(**kw) 
        
    def delete(self, fileUri, **kw):
        """ Removes the file from Smartling. The file will no longer be available for download. 
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Delete/ """
        return self.commandDelete(fileUri, **kw)        

    def status(self, fileUri):
        """ Returns information on a specific file.
            returns (response, status_code) tuple
            for details see  http://docs.smartling.com/pages/API/v2/FileAPI/Status/All-Locales/ """
        return self.commandStatus(fileUri)
        
    def status_locale(self, fileUri, locale):
        """ Returns detailed status information on a specific file.
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Status/Single-Locale/ """
        return self.commandStatusLocale(fileUri, locale)
        
    def rename(self, fileUri, newFileUrl):
        """ Renames an uploaded file by changing the fileUri.
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Rename/ """
        return self.commandRename(fileUri, newFileUrl)

    def last_modified(self, fileUri, localeId, **kw):
        """ Returns the date a file was last modified in a specified locale.
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Last-Modified/Single-Locale/ """
        return self.commandLastModified(fileUri, localeId, **kw)

    def last_modified_all(self, fileUri, **kw):
        """ Returns the date a file was last modified in a each locale
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Last-Modified/All-Locales/ """
        return self.commandLastModifiedAll(fileUri, **kw)    
        
    def import_call(self, filePathOriginal, filePathTranslated, fileType, localeId, **kw):
        """ Import Translations.
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Import-Translations/ """
        return self.commandImport(filePathOriginal, filePathTranslated, fileType, localeId, **kw)
        

    def list_authorized_locales(self, fileUri):
        """ Returns a list of locales the file is authorized for..
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/List-Authorized-Locales """
        return self.commandListAuthorizedLocales(fileUri)
        
    def authorize(self, fileUri, localeIds):
        """ Authorize a file for translation in the specified locales.
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/Authorize/ """
        return self.commandAuthorize(fileUri, localeIds)
        
    def unauthorize(self, fileUri, localeIds):
        """ Unauthorize a file for translation in the specified locales.
            returns (response, status_code) tuple
            for details see http://docs.smartling.com/pages/API/v2/FileAPI/Authorize-Content/Unauthorize/ / """
        return self.commandUnauthorize(fileUri, localeIds)
        
    def get_translations(self, fileUri, filePath, localeId, **kw):
        """ Temporarily uploads a file, then returns a translated version for requested locales.
            returns (response, status_code) tuple
            for http://docs.smartling.com/pages/API/v2/FileAPI/Get-Translations/ """
        return self.commandGetTranslations(fileUri, filePath, localeId, **kw)



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys
lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApiSdk.SmartlingFileApiV2 import SmartlingFileApiV2
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.Credentials import Credentials

#File attributes to upload to Smartling server
FILE_TYPE = "javaProperties"
FILE_NAME = "java.properties"
FILE_PATH = "../resources/"

#set Smartling creadentials via helper Credentials class
credentials = Credentials() #Gets your Smartling credetnials from environment variables
MY_USER_IDENTIFIER = credentials.MY_USER_IDENTIFIER
MY_USER_SECRET = credentials.MY_USER_SECRET
MY_PROJECT_ID = credentials.MY_PROJECT_ID
MY_LOCALE = credentials.MY_LOCALE

#set proxy settigns if necessary
useProxy = False
if useProxy :
    proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port")
else:
    proxySettings = None

#initializa api object
fapi = SmartlingFileApiV2( MY_USER_IDENTIFIER, MY_USER_SECRET, MY_PROJECT_ID, proxySettings)
        
#Upload file to Smartling
print "\nUploading ..."
path = FILE_PATH + FILE_NAME
resp, code = fapi.upload(path, FILE_TYPE, authorize="true")
print resp, code
if 200!=code:
    raise "failed"

#List uploaded files
print "\nList ..."
resp, code = fapi.list()
print code, resp

#check file status
print "\nFile status ..."
resp, code = fapi.status(path)
print code, resp

#read uplaoded file
print "\nRead file from server ..."
resp, code = fapi.get(path, MY_LOCALE)
print resp, code

#delete file
print "\nDelete file ..."
resp, code = fapi.delete(path)
print resp, code







#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

from setuptools import setup

setup(
    name="SmartlingApiSdk",
    version = "2.0.1",
    author="Smartling, Inc.",
    author_email="aartamonov@smartling.com",
    description="Smartling python library for file translations",
    license='Apache License v2.0',
    keywords='translation localization internationalization',
    url="https://docs.smartling.com/display/docs/Files+API",
    long_description="python SDK to work with Smartling API for file translation",
    packages=['smartlingApiSdk', "simplejson24", "example", "test"],
    include_package_data = True,
    package_data = {
        '': ['*.properties', '*.xml'],
    },
   
)



#!/usr/bin/python
# -*- coding: utf-8 -*-


''' Copyright 2012 Smartling, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this work except in compliance with the License.
 * You may obtain a copy of the License in the LICENSE file, or at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
'''

import os
import sys
import time

lib_path = os.path.abspath('../')
sys.path.append(lib_path)  # allow to import ../smartlingApiSdk/SmartlingFileApi

from smartlingApiSdk.SmartlingFileApi import SmartlingFileApi
from smartlingApiSdk.ProxySettings import ProxySettings
from smartlingApiSdk.UploadData import UploadData
from nose.tools import assert_equal

# don't forget to set real API_KEY and PROJECT_ID
# or use environment variables:
# export SL_API_KEY=********-****-****-****-************
# export SL_PROJECT_ID=*******
# export SL_LOCALE=**-**


class testImport(object):
    MY_API_KEY = "YOUR_API_KEY"
    MY_PROJECT_ID = "YOUR_PROJECT_ID"
    SL_LOCALE = "ru-RU"

    FILE_PATH = "../resources/"
    CALLBACK_URL = "http://google.com/?q=hello"

    FILE_NAME = "test_import.xml"
    FILE_NAME_IMPORT = "test_import_es.xml"
    FILE_TYPE = "android"
    HOST = 'api.smartling.com'


    CODE_SUCCESS_TOKEN = 'SUCCESS'

    def setUp(self):
        self.MY_API_KEY = os.environ.get('SL_API_KEY', self.MY_API_KEY)
        self.MY_PROJECT_ID = os.environ.get('SL_PROJECT_ID', self.MY_PROJECT_ID)
        useProxy = False
        if useProxy :
            proxySettings = ProxySettings("login", "password", "proxy_host", "proxy_port or None")
        else:
            proxySettings = None        
        self.fapi = SmartlingFileApi(self.HOST, self.MY_API_KEY, self.MY_PROJECT_ID, proxySettings)
        self.locale =  os.environ.get('SL_LOCALE', self.SL_LOCALE)
        timestamp = `time.time()`
        self.uri = self.FILE_NAME + timestamp
        self.doUpload(self.uri)

    def doUpload(self, uri):
        #ensure file is uploaded which is necessary for all tests
        uploadData = UploadData(self.FILE_PATH, self.FILE_NAME, self.FILE_TYPE)
        uploadData.setCallbackUrl(self.CALLBACK_URL)
        uploadData.setUri(uri)
        return self.fapi.upload(uploadData)

    def tearDown(self):
        print self.fapi.delete(self.uri)
        
    def testImport(self):
        uploadData = UploadData(self.FILE_PATH, self.FILE_NAME, self.FILE_TYPE)
        uploadData.uri = self.uri
        uploadData.name = self.FILE_NAME_IMPORT
        resp, status = self.fapi.import_call(uploadData, self.locale, translationState="PUBLISHED")
        assert_equal(resp.code, self.CODE_SUCCESS_TOKEN)
        assert_equal(resp.data.wordCount, 2)
        assert_equal(resp.data.stringCount, 2)
        assert_equal(resp.data.translationImportErrors, [])

